==> cds-services-utils-1.18.1-sources.jar: com/sap/cds/services/utils/index/IndexPageServlet.java <==
/**************************************************************************
 * (C) 2019-2021 SAP SE or an SAP affiliate company. All rights reserved. *
 **************************************************************************/
package com.sap.cds.services.utils.index;

import java.io.IOException;
import java.io.PrintWriter;
import java.util.Collections;
import java.util.List;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.sap.cds.adapter.IndexContentProvider;

public class IndexPageServlet extends HttpServlet {

	private static final long serialVersionUID = 1L;

	private static final String START = "" +
			"<!DOCTYPE html>\n" +
			"    <html>\n" +
			"        <head>\n" +
			"            <style>\n" +
			"                body { margin: 44px; font-family: Avenir Next, sans-serif }\n" +
			"            </style>\n" +
			"        </head>\n" +
			"        <body>\n" +
			"            <h1> Welcome to <i>cds-services</i> </h1>\n" +
			"            <p> These are the paths currently served &hellip;\n" +
			"            <p></p>\n";

	private static final String SECTION_TITLE = "" +
			"            <br>\n" +
			"            <h3>%s</h3>\n";

	private static final String END = "" +
			"            \n" +
			"        </body>\n" +
			"    </html>";


	private List<IndexContentProvider> contentProviders;

	public IndexPageServlet(List<IndexContentProvider> contentProviders) {
		this.contentProviders = Collections.unmodifiableList(contentProviders);
	}


	@Override
	protected void service(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
		resp.setContentType("text/html");

		PrintWriter out = resp.getWriter();
		out.write(START);

		String contextPath = getServletConfig() == null ? "" : getServletConfig().getServletContext().getContextPath();

		for (IndexContentProvider provider : contentProviders) {
			out.format(SECTION_TITLE, provider.getSectionTitle());
			provider.writeContent(out, contextPath);
		}

		out.write(END);
	}

}

==> cds-services-utils-2.4.1-sources.jar: com/sap/cds/services/utils/index/IndexPageServlet.java <==
/**************************************************************************
 * (C) 2019-2021 SAP SE or an SAP affiliate company. All rights reserved. *
 **************************************************************************/
package com.sap.cds.services.utils.index;

import java.io.IOException;
import java.io.PrintWriter;
import java.util.Collections;
import java.util.List;

import jakarta.servlet.ServletException;
import jakarta.servlet.http.HttpServlet;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;

import com.sap.cds.adapter.IndexContentProvider;

public class IndexPageServlet extends HttpServlet {

	private static final long serialVersionUID = 1L;

	private static final String START = "" +
			"<!DOCTYPE html>\n" +
			"    <html>\n" +
			"        <head>\n" +
			"            <style>\n" +
			"                body { margin: 44px; font-family: Avenir Next, sans-serif }\n" +
			"            </style>\n" +
			"        </head>\n" +
			"        <body>\n" +
			"            <h1> Welcome to <i>cds-services</i> </h1>\n" +
			"            <p> These are the paths currently served &hellip;\n" +
			"            <p></p>\n";

	private static final String SECTION_TITLE = "" +
			"            <br>\n" +
			"            <h3>%s</h3>\n";

	private static final String END = "" +
			"            \n" +
			"        </body>\n" +
			"    </html>";


	private List<IndexContentProvider> contentProviders;

	public IndexPageServlet(List<IndexContentProvider> contentProviders) {
		this.contentProviders = Collections.unmodifiableList(contentProviders);
	}


	@Override
	protected void service(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
		resp.setContentType("text/html");

		PrintWriter out = resp.getWriter();
		out.write(START);

		String contextPath = getServletConfig() == null ? req.getContextPath() : getServletConfig().getServletContext().getContextPath();

		for (IndexContentProvider provider : contentProviders) {
			out.format(SECTION_TITLE, provider.getSectionTitle());
			provider.writeContent(out, contextPath);
		}

		out.write(END);
	}

}
